@@ -57,7 +57,8 @@ class ScoreComponentFactory:
             enum.HERG_PIP: PiPPredictionComponent,
             enum.RAT_PK_PIP: RatPKPiP,
             enum.CLAB_TOP_20: Top20,
-            enum.RA_SCORE: PiPPredictionComponent
+            enum.RA_SCORE: PiPPredictionComponent,
+            enum.KPUU_PIP: PiPLogPredictionComponent
         }
         return component_map
 
